% 56x56 Macaulay multiresultant matrix for 4 point DLT-like pose method.
% Using the DLT on 4 known 3D points, the possible projection matrices
% have been reduced to a 4 parameter family P = u1*P1+..+u4*P4 where
% (u1..u4) are unknown parameters.  We use 4 supplementary calibration
% constraints aspect_ratio = 1, skew=0, principal_point=(0,0) (i.e.
% w(1,1)-w(2,2) = w(1,2) = w(1,3) = w(2,3) = 0 where w is the DIAC) to
% eliminate (u1..u4) and solve for P, camera pose, calibration, etc.
% The redundancy is 1 (since u1..u4 are only defined up to scale), so a
% linear solution is possible.  The constraints are all quadratic in
% (u1..u4). Each row of the 4x10 input matrix M represents one of these
% homogeneous quadratics (i.e. it is a flattened 4x4 symmetric
% matrix). The output multiresultant matrix has rank 79 in the noiseless
% case (but alas only 76 for coplanar points). The last 4 components of
% its null vector are (...u1..u4), which in turn gives P, pose, etc. The
% matrix was calculated with Maple using my extended multiresultant
% routine xmultires().

function [u,cond] = dlt4multires0(M);
   A = zeros(56,56);
   A(1,47) = M(1,1);
   A(2,39) = M(1,1);
   A(3,38) = M(1,1);
   A(4,37) = M(1,1);
   A(5,26) = M(1,1);
   A(6,24) = M(1,1);
   A(7,23) = M(1,1);
   A(8,5) = M(1,1);
   A(1,48) = M(1,2);
   A(2,41) = M(1,2);
   A(3,40) = M(1,2);
   A(4,38) = M(1,2);
   A(5,29) = M(1,2);
   A(6,26) = M(1,2);
   A(7,25) = M(1,2);
   A(8,8) = M(1,2);
   A(1,50) = M(1,3);
   A(2,44) = M(1,3);
   A(3,43) = M(1,3);
   A(4,40) = M(1,3);
   A(5,33) = M(1,3);
   A(6,29) = M(1,3);
   A(7,28) = M(1,3);
   A(8,12) = M(1,3);
   A(1,49) = M(1,4);
   A(2,42) = M(1,4);
   A(3,41) = M(1,4);
   A(4,39) = M(1,4);
   A(5,30) = M(1,4);
   A(6,27) = M(1,4);
   A(7,26) = M(1,4);
   A(8,9) = M(1,4);
   A(1,51) = M(1,5);
   A(2,45) = M(1,5);
   A(3,44) = M(1,5);
   A(4,41) = M(1,5);
   A(5,34) = M(1,5);
   A(6,30) = M(1,5);
   A(7,29) = M(1,5);
   A(8,13) = M(1,5);
   A(1,52) = M(1,6);
   A(2,46) = M(1,6);
   A(3,45) = M(1,6);
   A(4,42) = M(1,6);
   A(5,35) = M(1,6);
   A(6,31) = M(1,6);
   A(7,30) = M(1,6);
   A(8,14) = M(1,6);
   A(1,53) = M(1,7);
   A(2,49) = M(1,7);
   A(3,48) = M(1,7);
   A(4,47) = M(1,7);
   A(5,41) = M(1,7);
   A(6,39) = M(1,7);
   A(7,38) = M(1,7);
   A(8,26) = M(1,7);
   A(1,54) = M(1,8);
   A(2,51) = M(1,8);
   A(3,50) = M(1,8);
   A(4,48) = M(1,8);
   A(5,44) = M(1,8);
   A(6,41) = M(1,8);
   A(7,40) = M(1,8);
   A(8,29) = M(1,8);
   A(1,55) = M(1,9);
   A(2,52) = M(1,9);
   A(3,51) = M(1,9);
   A(4,49) = M(1,9);
   A(5,45) = M(1,9);
   A(6,42) = M(1,9);
   A(7,41) = M(1,9);
   A(8,30) = M(1,9);
   A(1,56) = M(1,10);
   A(2,55) = M(1,10);
   A(3,54) = M(1,10);
   A(4,53) = M(1,10);
   A(5,51) = M(1,10);
   A(6,49) = M(1,10);
   A(7,48) = M(1,10);
   A(8,41) = M(1,10);
   A(9,47) = M(2,1);
   A(10,39) = M(2,1);
   A(11,38) = M(2,1);
   A(12,37) = M(2,1);
   A(13,26) = M(2,1);
   A(14,24) = M(2,1);
   A(15,23) = M(2,1);
   A(16,22) = M(2,1);
   A(17,5) = M(2,1);
   A(18,3) = M(2,1);
   A(19,2) = M(2,1);
   A(20,1) = M(2,1);
   A(9,48) = M(2,2);
   A(10,41) = M(2,2);
   A(11,40) = M(2,2);
   A(12,38) = M(2,2);
   A(13,29) = M(2,2);
   A(14,26) = M(2,2);
   A(15,25) = M(2,2);
   A(16,23) = M(2,2);
   A(17,8) = M(2,2);
   A(18,5) = M(2,2);
   A(19,4) = M(2,2);
   A(20,2) = M(2,2);
   A(9,50) = M(2,3);
   A(10,44) = M(2,3);
   A(11,43) = M(2,3);
   A(12,40) = M(2,3);
   A(13,33) = M(2,3);
   A(14,29) = M(2,3);
   A(15,28) = M(2,3);
   A(16,25) = M(2,3);
   A(17,12) = M(2,3);
   A(18,8) = M(2,3);
   A(19,7) = M(2,3);
   A(20,4) = M(2,3);
   A(9,49) = M(2,4);
   A(10,42) = M(2,4);
   A(11,41) = M(2,4);
   A(12,39) = M(2,4);
   A(13,30) = M(2,4);
   A(14,27) = M(2,4);
   A(15,26) = M(2,4);
   A(16,24) = M(2,4);
   A(17,9) = M(2,4);
   A(18,6) = M(2,4);
   A(19,5) = M(2,4);
   A(20,3) = M(2,4);
   A(9,51) = M(2,5);
   A(10,45) = M(2,5);
   A(11,44) = M(2,5);
   A(12,41) = M(2,5);
   A(13,34) = M(2,5);
   A(14,30) = M(2,5);
   A(15,29) = M(2,5);
   A(16,26) = M(2,5);
   A(17,13) = M(2,5);
   A(18,9) = M(2,5);
   A(19,8) = M(2,5);
   A(20,5) = M(2,5);
   A(9,52) = M(2,6);
   A(10,46) = M(2,6);
   A(11,45) = M(2,6);
   A(12,42) = M(2,6);
   A(13,35) = M(2,6);
   A(14,31) = M(2,6);
   A(15,30) = M(2,6);
   A(16,27) = M(2,6);
   A(17,14) = M(2,6);
   A(18,10) = M(2,6);
   A(19,9) = M(2,6);
   A(20,6) = M(2,6);
   A(9,53) = M(2,7);
   A(10,49) = M(2,7);
   A(11,48) = M(2,7);
   A(12,47) = M(2,7);
   A(13,41) = M(2,7);
   A(14,39) = M(2,7);
   A(15,38) = M(2,7);
   A(16,37) = M(2,7);
   A(17,26) = M(2,7);
   A(18,24) = M(2,7);
   A(19,23) = M(2,7);
   A(20,22) = M(2,7);
   A(9,54) = M(2,8);
   A(10,51) = M(2,8);
   A(11,50) = M(2,8);
   A(12,48) = M(2,8);
   A(13,44) = M(2,8);
   A(14,41) = M(2,8);
   A(15,40) = M(2,8);
   A(16,38) = M(2,8);
   A(17,29) = M(2,8);
   A(18,26) = M(2,8);
   A(19,25) = M(2,8);
   A(20,23) = M(2,8);
   A(9,55) = M(2,9);
   A(10,52) = M(2,9);
   A(11,51) = M(2,9);
   A(12,49) = M(2,9);
   A(13,45) = M(2,9);
   A(14,42) = M(2,9);
   A(15,41) = M(2,9);
   A(16,39) = M(2,9);
   A(17,30) = M(2,9);
   A(18,27) = M(2,9);
   A(19,26) = M(2,9);
   A(20,24) = M(2,9);
   A(9,56) = M(2,10);
   A(10,55) = M(2,10);
   A(11,54) = M(2,10);
   A(12,53) = M(2,10);
   A(13,51) = M(2,10);
   A(14,49) = M(2,10);
   A(15,48) = M(2,10);
   A(16,47) = M(2,10);
   A(17,41) = M(2,10);
   A(18,39) = M(2,10);
   A(19,38) = M(2,10);
   A(20,37) = M(2,10);
   A(21,47) = M(3,1);
   A(22,39) = M(3,1);
   A(23,38) = M(3,1);
   A(24,37) = M(3,1);
   A(25,26) = M(3,1);
   A(26,25) = M(3,1);
   A(27,24) = M(3,1);
   A(28,23) = M(3,1);
   A(29,22) = M(3,1);
   A(30,8) = M(3,1);
   A(31,7) = M(3,1);
   A(32,5) = M(3,1);
   A(33,4) = M(3,1);
   A(34,3) = M(3,1);
   A(35,2) = M(3,1);
   A(36,1) = M(3,1);
   A(21,48) = M(3,2);
   A(22,41) = M(3,2);
   A(23,40) = M(3,2);
   A(24,38) = M(3,2);
   A(25,29) = M(3,2);
   A(26,28) = M(3,2);
   A(27,26) = M(3,2);
   A(28,25) = M(3,2);
   A(29,23) = M(3,2);
   A(30,12) = M(3,2);
   A(31,11) = M(3,2);
   A(32,8) = M(3,2);
   A(33,7) = M(3,2);
   A(34,5) = M(3,2);
   A(35,4) = M(3,2);
   A(36,2) = M(3,2);
   A(21,50) = M(3,3);
   A(22,44) = M(3,3);
   A(23,43) = M(3,3);
   A(24,40) = M(3,3);
   A(25,33) = M(3,3);
   A(26,32) = M(3,3);
   A(27,29) = M(3,3);
   A(28,28) = M(3,3);
   A(29,25) = M(3,3);
   A(30,17) = M(3,3);
   A(31,16) = M(3,3);
   A(32,12) = M(3,3);
   A(33,11) = M(3,3);
   A(34,8) = M(3,3);
   A(35,7) = M(3,3);
   A(36,4) = M(3,3);
   A(21,49) = M(3,4);
   A(22,42) = M(3,4);
   A(23,41) = M(3,4);
   A(24,39) = M(3,4);
   A(25,30) = M(3,4);
   A(26,29) = M(3,4);
   A(27,27) = M(3,4);
   A(28,26) = M(3,4);
   A(29,24) = M(3,4);
   A(30,13) = M(3,4);
   A(31,12) = M(3,4);
   A(32,9) = M(3,4);
   A(33,8) = M(3,4);
   A(34,6) = M(3,4);
   A(35,5) = M(3,4);
   A(36,3) = M(3,4);
   A(21,51) = M(3,5);
   A(22,45) = M(3,5);
   A(23,44) = M(3,5);
   A(24,41) = M(3,5);
   A(25,34) = M(3,5);
   A(26,33) = M(3,5);
   A(27,30) = M(3,5);
   A(28,29) = M(3,5);
   A(29,26) = M(3,5);
   A(30,18) = M(3,5);
   A(31,17) = M(3,5);
   A(32,13) = M(3,5);
   A(33,12) = M(3,5);
   A(34,9) = M(3,5);
   A(35,8) = M(3,5);
   A(36,5) = M(3,5);
   A(21,52) = M(3,6);
   A(22,46) = M(3,6);
   A(23,45) = M(3,6);
   A(24,42) = M(3,6);
   A(25,35) = M(3,6);
   A(26,34) = M(3,6);
   A(27,31) = M(3,6);
   A(28,30) = M(3,6);
   A(29,27) = M(3,6);
   A(30,19) = M(3,6);
   A(31,18) = M(3,6);
   A(32,14) = M(3,6);
   A(33,13) = M(3,6);
   A(34,10) = M(3,6);
   A(35,9) = M(3,6);
   A(36,6) = M(3,6);
   A(21,53) = M(3,7);
   A(22,49) = M(3,7);
   A(23,48) = M(3,7);
   A(24,47) = M(3,7);
   A(25,41) = M(3,7);
   A(26,40) = M(3,7);
   A(27,39) = M(3,7);
   A(28,38) = M(3,7);
   A(29,37) = M(3,7);
   A(30,29) = M(3,7);
   A(31,28) = M(3,7);
   A(32,26) = M(3,7);
   A(33,25) = M(3,7);
   A(34,24) = M(3,7);
   A(35,23) = M(3,7);
   A(36,22) = M(3,7);
   A(21,54) = M(3,8);
   A(22,51) = M(3,8);
   A(23,50) = M(3,8);
   A(24,48) = M(3,8);
   A(25,44) = M(3,8);
   A(26,43) = M(3,8);
   A(27,41) = M(3,8);
   A(28,40) = M(3,8);
   A(29,38) = M(3,8);
   A(30,33) = M(3,8);
   A(31,32) = M(3,8);
   A(32,29) = M(3,8);
   A(33,28) = M(3,8);
   A(34,26) = M(3,8);
   A(35,25) = M(3,8);
   A(36,23) = M(3,8);
   A(21,55) = M(3,9);
   A(22,52) = M(3,9);
   A(23,51) = M(3,9);
   A(24,49) = M(3,9);
   A(25,45) = M(3,9);
   A(26,44) = M(3,9);
   A(27,42) = M(3,9);
   A(28,41) = M(3,9);
   A(29,39) = M(3,9);
   A(30,34) = M(3,9);
   A(31,33) = M(3,9);
   A(32,30) = M(3,9);
   A(33,29) = M(3,9);
   A(34,27) = M(3,9);
   A(35,26) = M(3,9);
   A(36,24) = M(3,9);
   A(21,56) = M(3,10);
   A(22,55) = M(3,10);
   A(23,54) = M(3,10);
   A(24,53) = M(3,10);
   A(25,51) = M(3,10);
   A(26,50) = M(3,10);
   A(27,49) = M(3,10);
   A(28,48) = M(3,10);
   A(29,47) = M(3,10);
   A(30,44) = M(3,10);
   A(31,43) = M(3,10);
   A(32,41) = M(3,10);
   A(33,40) = M(3,10);
   A(34,39) = M(3,10);
   A(35,38) = M(3,10);
   A(36,37) = M(3,10);
   A(37,47) = M(4,1);
   A(38,39) = M(4,1);
   A(39,38) = M(4,1);
   A(40,37) = M(4,1);
   A(41,27) = M(4,1);
   A(42,26) = M(4,1);
   A(43,25) = M(4,1);
   A(44,24) = M(4,1);
   A(45,23) = M(4,1);
   A(46,22) = M(4,1);
   A(47,10) = M(4,1);
   A(48,9) = M(4,1);
   A(49,8) = M(4,1);
   A(50,7) = M(4,1);
   A(51,6) = M(4,1);
   A(52,5) = M(4,1);
   A(53,4) = M(4,1);
   A(54,3) = M(4,1);
   A(55,2) = M(4,1);
   A(56,1) = M(4,1);
   A(37,48) = M(4,2);
   A(38,41) = M(4,2);
   A(39,40) = M(4,2);
   A(40,38) = M(4,2);
   A(41,30) = M(4,2);
   A(42,29) = M(4,2);
   A(43,28) = M(4,2);
   A(44,26) = M(4,2);
   A(45,25) = M(4,2);
   A(46,23) = M(4,2);
   A(47,14) = M(4,2);
   A(48,13) = M(4,2);
   A(49,12) = M(4,2);
   A(50,11) = M(4,2);
   A(51,9) = M(4,2);
   A(52,8) = M(4,2);
   A(53,7) = M(4,2);
   A(54,5) = M(4,2);
   A(55,4) = M(4,2);
   A(56,2) = M(4,2);
   A(37,50) = M(4,3);
   A(38,44) = M(4,3);
   A(39,43) = M(4,3);
   A(40,40) = M(4,3);
   A(41,34) = M(4,3);
   A(42,33) = M(4,3);
   A(43,32) = M(4,3);
   A(44,29) = M(4,3);
   A(45,28) = M(4,3);
   A(46,25) = M(4,3);
   A(47,19) = M(4,3);
   A(48,18) = M(4,3);
   A(49,17) = M(4,3);
   A(50,16) = M(4,3);
   A(51,13) = M(4,3);
   A(52,12) = M(4,3);
   A(53,11) = M(4,3);
   A(54,8) = M(4,3);
   A(55,7) = M(4,3);
   A(56,4) = M(4,3);
   A(37,49) = M(4,4);
   A(38,42) = M(4,4);
   A(39,41) = M(4,4);
   A(40,39) = M(4,4);
   A(41,31) = M(4,4);
   A(42,30) = M(4,4);
   A(43,29) = M(4,4);
   A(44,27) = M(4,4);
   A(45,26) = M(4,4);
   A(46,24) = M(4,4);
   A(47,15) = M(4,4);
   A(48,14) = M(4,4);
   A(49,13) = M(4,4);
   A(50,12) = M(4,4);
   A(51,10) = M(4,4);
   A(52,9) = M(4,4);
   A(53,8) = M(4,4);
   A(54,6) = M(4,4);
   A(55,5) = M(4,4);
   A(56,3) = M(4,4);
   A(37,51) = M(4,5);
   A(38,45) = M(4,5);
   A(39,44) = M(4,5);
   A(40,41) = M(4,5);
   A(41,35) = M(4,5);
   A(42,34) = M(4,5);
   A(43,33) = M(4,5);
   A(44,30) = M(4,5);
   A(45,29) = M(4,5);
   A(46,26) = M(4,5);
   A(47,20) = M(4,5);
   A(48,19) = M(4,5);
   A(49,18) = M(4,5);
   A(50,17) = M(4,5);
   A(51,14) = M(4,5);
   A(52,13) = M(4,5);
   A(53,12) = M(4,5);
   A(54,9) = M(4,5);
   A(55,8) = M(4,5);
   A(56,5) = M(4,5);
   A(37,52) = M(4,6);
   A(38,46) = M(4,6);
   A(39,45) = M(4,6);
   A(40,42) = M(4,6);
   A(41,36) = M(4,6);
   A(42,35) = M(4,6);
   A(43,34) = M(4,6);
   A(44,31) = M(4,6);
   A(45,30) = M(4,6);
   A(46,27) = M(4,6);
   A(47,21) = M(4,6);
   A(48,20) = M(4,6);
   A(49,19) = M(4,6);
   A(50,18) = M(4,6);
   A(51,15) = M(4,6);
   A(52,14) = M(4,6);
   A(53,13) = M(4,6);
   A(54,10) = M(4,6);
   A(55,9) = M(4,6);
   A(56,6) = M(4,6);
   A(37,53) = M(4,7);
   A(38,49) = M(4,7);
   A(39,48) = M(4,7);
   A(40,47) = M(4,7);
   A(41,42) = M(4,7);
   A(42,41) = M(4,7);
   A(43,40) = M(4,7);
   A(44,39) = M(4,7);
   A(45,38) = M(4,7);
   A(46,37) = M(4,7);
   A(47,31) = M(4,7);
   A(48,30) = M(4,7);
   A(49,29) = M(4,7);
   A(50,28) = M(4,7);
   A(51,27) = M(4,7);
   A(52,26) = M(4,7);
   A(53,25) = M(4,7);
   A(54,24) = M(4,7);
   A(55,23) = M(4,7);
   A(56,22) = M(4,7);
   A(37,54) = M(4,8);
   A(38,51) = M(4,8);
   A(39,50) = M(4,8);
   A(40,48) = M(4,8);
   A(41,45) = M(4,8);
   A(42,44) = M(4,8);
   A(43,43) = M(4,8);
   A(44,41) = M(4,8);
   A(45,40) = M(4,8);
   A(46,38) = M(4,8);
   A(47,35) = M(4,8);
   A(48,34) = M(4,8);
   A(49,33) = M(4,8);
   A(50,32) = M(4,8);
   A(51,30) = M(4,8);
   A(52,29) = M(4,8);
   A(53,28) = M(4,8);
   A(54,26) = M(4,8);
   A(55,25) = M(4,8);
   A(56,23) = M(4,8);
   A(37,55) = M(4,9);
   A(38,52) = M(4,9);
   A(39,51) = M(4,9);
   A(40,49) = M(4,9);
   A(41,46) = M(4,9);
   A(42,45) = M(4,9);
   A(43,44) = M(4,9);
   A(44,42) = M(4,9);
   A(45,41) = M(4,9);
   A(46,39) = M(4,9);
   A(47,36) = M(4,9);
   A(48,35) = M(4,9);
   A(49,34) = M(4,9);
   A(50,33) = M(4,9);
   A(51,31) = M(4,9);
   A(52,30) = M(4,9);
   A(53,29) = M(4,9);
   A(54,27) = M(4,9);
   A(55,26) = M(4,9);
   A(56,24) = M(4,9);
   A(37,56) = M(4,10);
   A(38,55) = M(4,10);
   A(39,54) = M(4,10);
   A(40,53) = M(4,10);
   A(41,52) = M(4,10);
   A(42,51) = M(4,10);
   A(43,50) = M(4,10);
   A(44,49) = M(4,10);
   A(45,48) = M(4,10);
   A(46,47) = M(4,10);
   A(47,46) = M(4,10);
   A(48,45) = M(4,10);
   A(49,44) = M(4,10);
   A(50,43) = M(4,10);
   A(51,42) = M(4,10);
   A(52,41) = M(4,10);
   A(53,40) = M(4,10);
   A(54,39) = M(4,10);
   A(55,38) = M(4,10);
   A(56,37) = M(4,10);

   [U,S,V] = svd(A);
   S = diag(S)';
   cond = [S(55)/S(1), S(56)/S(55)];
   v = V(:,56);
   % To get most accurate ratios of u.i's, select largest 
   % column from uu = const * [u1;u2;u3;u4] * [u1,u2,u3,u4].^4 
   uu = [v([1,2,3,22]), ...
	  v([11,16,17,32]), ...
	  v([15,20,21,36]), ...
	  v([53,54,55,56]) ];
   nu = sum(uu.^2);
   % uu ./ (ones(4,1)*sqrt(nu))
   i = 1;
   for j=2:4 
      if (nu(j)>nu(i)) i=j; end;
   end;
   u = uu(:,i);
end;
